<?php

/**
 * @var \Illuminate\Database\Eloquent\Collection $event
 * @var int $page_number
 * @var \kernel\CgView $view
 */

use kernel\app_modules\event\models\EventContact;
use Itguild\EloquentTable\EloquentDataProvider;
use Itguild\EloquentTable\ListEloquentTable;
use kernel\widgets\IconBtn\IconBtnCreateWidget;
use kernel\widgets\IconBtn\IconBtnDeleteWidget;
use kernel\widgets\IconBtn\IconBtnEditWidget;
use kernel\widgets\IconBtn\IconBtnViewWidget;

$view->setTitle("Список event contacts");
$view->setMeta([
    'description' => 'Список event contacts системы'
]);

//Для использования таблицы с моделью, необходимо создать таблицу в базе данных
$table = new ListEloquentTable(new EloquentDataProvider(EventContact::class, [
    'currentPage' => $page_number,
    'perPage' => 8,
    'params' => ["class" => "table table-bordered", "border" => "2"],
    'baseUrl' => "/admin/event-contacts"
]));


//$table = new \Itguild\Tables\ListJsonTable(json_encode(
//    [
//        'meta' => [
//            'total' => 0,
//            'totalWithFilters' => 0,
//            'columns' => [
//                'title',
//                'slug',
//                'status',
//            ],
//            'perPage' => 5,
//            'currentPage' => 1,
//            'baseUrl' => '/admin/some',
//            'params' => [
//                'class' => 'table table-bordered',
//                'border' => 2
//            ]
//        ],
//        'filters' => [],
//        'data' => [],
//    ]
//));

// Пример фильтра
$table->columns([
    'title' => [
        'filter' => [
            'class' => \Itguild\Tables\Filter\InputTextFilter::class,
            'value' => $get['title'] ?? ''
        ]
    ],
    'event_id' => [
        'value' => function ($data) {
            $model = \kernel\app_modules\event\models\Event::find($data);
            return $model->title ?? '';
        }
    ],
    'status' => [
        'value' => function ($data) {
            return EventContact::getStatus()[$data];
        }
    ]
]);

$table->beforePrint(function () {
    return IconBtnCreateWidget::create(['url' => '/admin/event-contacts/create'])->run();
});

$table->addAction(function($row) {
    return IconBtnViewWidget::create(['url' => '/admin/event-contacts/view/' . $row['id']])->run();
});
$table->addAction(function($row) {
    return IconBtnEditWidget::create(['url' => '/admin/event-contacts/update/' . $row['id']])->run();
});
$table->addAction(function($row) {
    return IconBtnDeleteWidget::create(['url' => '/admin/event-contacts/delete/' . $row['id']])->run();
});
$table->create();
$table->render();